MetricResults
=============

.. currentmodule:: pykeen.evaluation

.. autoclass:: MetricResults
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~MetricResults.get_metric
      ~MetricResults.to_flat_dict

   .. rubric:: Methods Documentation

   .. automethod:: get_metric
   .. automethod:: to_flat_dict
